/**************************************************************************
 |                                                                         
 |                    STATA SETUP FILE FOR ICPSR 03404
 |       DRUG ABUSE TREATMENT OUTCOME STUDY--ADOLESCENT (DATOS-A),
 |                       1993-1995: [UNITED STATES]
 |            (DATASET 0006:  TIME IN TREATMENT AND INTERVIEW
 |                        AVAILABILITY INDICATORS)
 |
 |
 |  Please edit this file as instructed below.
 |  To execute, start Stata, change to the directory containing:
 |       - this do file
 |       - the ASCII data file
 |       - the dictionary file
 |
 |  Then execute the do file (e.g., do 03404-0006-statasetup.do)
 |
 **************************************************************************/

set mem 6m  /* Allocating 6 megabyte(s) of RAM for Stata SE to read the
                 data file into memory. */


set more off  /* This prevents the Stata output viewer from pausing the
                 process */

/****************************************************

Section 1: File Specifications
   This section assigns local macros to the necessary files.
   Please edit:
        "data-filename" ==> The name of data file downloaded from ICPSR
        "dictionary-filename" ==> The name of the dictionary file downloaded.
        "stata-datafile" ==> The name you wish to call your Stata data file.

   Note:  We assume that the raw data, dictionary, and setup (this do file) all
          reside in the same directory (or folder).  If that is not the case
          you will need to include paths as well as filenames in the macros.

********************************************************/

local raw_data "data-filename"
local dict "dictionary-filename"
local outfile "stata-datafile"

/********************************************************

Section 2: Infile Command

This section reads the raw data into Stata format.  If Section 1 was defined
properly, there should be no reason to modify this section.  These macros
should inflate automatically.

**********************************************************/

infile using `dict', using (`raw_data') clear


/*********************************************************

Section 3: Value Label Definitions
This section defines labels for the individual values of each variable.
We suggest that users do not modify this section.

**********************************************************/


label data "Drug Abuse Treatment Outcome Study--Adolescent (DATOS-A), 1993-1995: [United States], Dataset 0006"

#delimit ;
label define MODALITY  1 "RESIDENTIAL" 2 "SHORT-TERM INPATIENT"
                       4 "OUTPATIENT DRUG FREE" ;
label define INTAKE1   1 "INTAKE-1 AVAILABLE" ;
label define INTAKE2   0 "NO INTAKE-2" 1 "INTAKE-2 AVAILABLE" ;
label define ONEMONTH  0 "NO 1-MONTH INTERVIEW"
                       1 "1-MONTH INTERVIEW AVAILABLE" ;
label define THRMONTH  0 "NO 3-MONTH INTERVIEW"
                       1 "3-MONTH INTERVIEW AVAILABLE" ;
label define SIXMONTH  0 "NO 6-MONTH INTERVIEW"
                       1 "6-MONTH INTERVIEW AVAILABLE" ;
label define FUP12     0 "NO FOLLOWUP INTERVIEW"
                       1 "FOLLOWUP INTERVIEW AVAILABLE" ;
label define DAYSIN    -9 "MISSING" ;


#delimit cr


/***************************************************************************

 Section 4: Missing Values

 This section will replace numeric missing values (i.e., -9) with generic
 system missing ".".  By default the code in this section is commented out.
 Users wishing to apply the generic missing values should remove the comment
 at the beginning and end of this section.  Note that Stata allows you to
 specify up to 27 unique missing value codes.

****************************************************************/

/*
replace DAYSIN = . if (DAYSIN == -9)


*/
/********************************************************************

 Section 5: Save Outfile

  This section saves out a Stata system format file.  There is no reason to
  modify it if the macros in Section 1 were specified correctly.

*********************************************************************/

save `outfile', replace

